==> jc-1.4.0.tar.gz: java/awt/DefaultFocusTraversalPolicy.h <==
// public class java.awt.DefaultFocusTraversalPolicy

// class file dependencies
// @dep_class 4ebbf65a7d711c64 java_awt_ContainerOrderFocusTraversalPolicy
// @dep_class a5212854707fc4d5 java_awt_DefaultFocusTraversalPolicy
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_ContainerOrderFocusTraversalPolicy

#include "java/awt/ContainerOrderFocusTraversalPolicy.h"

#ifndef _JC_java_awt_DefaultFocusTraversalPolicy_H_
#define _JC_java_awt_DefaultFocusTraversalPolicy_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_refs	_jc_java_awt_DefaultFocusTraversalPolicy$sub_refs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs	_jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$refs	_jc_java_awt_DefaultFocusTraversalPolicy$refs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$nonrefs	_jc_java_awt_DefaultFocusTraversalPolicy$nonrefs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$object	_jc_java_awt_DefaultFocusTraversalPolicy$object;

typedef const struct _jc_java_awt_DefaultFocusTraversalPolicy$vmethods	_jc_java_awt_DefaultFocusTraversalPolicy$vmethods;
typedef const struct _jc_java_awt_DefaultFocusTraversalPolicy$vtable	_jc_java_awt_DefaultFocusTraversalPolicy$vtable;
typedef const struct _jc_java_awt_DefaultFocusTraversalPolicy$vtype	_jc_java_awt_DefaultFocusTraversalPolicy$vtype;

// Constructors
extern void _jc_java_awt_DefaultFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_DefaultFocusTraversalPolicy$object *);

// Virtual methods
extern jboolean _jc_java_awt_DefaultFocusTraversalPolicy$method$accept$ef92c67fd1dc07ff(_jc_env *, struct _jc_java_awt_DefaultFocusTraversalPolicy$object *, struct _jc_java_awt_Component$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_DefaultFocusTraversalPolicy$method_info$accept$ef92c67fd1dc07ff;

// Virtual methods structure
struct _jc_java_awt_DefaultFocusTraversalPolicy$vmethods {
	jboolean	(*accept$ef92c67fd1dc07ff)(_jc_env *, struct _jc_java_awt_DefaultFocusTraversalPolicy$object *, struct _jc_java_awt_Component$object *);
};

// Vtable
struct _jc_java_awt_DefaultFocusTraversalPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FocusTraversalPolicy$vmethods	java_awt_FocusTraversalPolicy;
	_jc_java_awt_ContainerOrderFocusTraversalPolicy$vmethods	java_awt_ContainerOrderFocusTraversalPolicy;
	_jc_java_awt_DefaultFocusTraversalPolicy$vmethods	java_awt_DefaultFocusTraversalPolicy;
};

// Vtype
struct _jc_java_awt_DefaultFocusTraversalPolicy$vtype {
	_jc_type			type;
	_jc_java_awt_DefaultFocusTraversalPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_DefaultFocusTraversalPolicy$refs {
    _jc_java_awt_DefaultFocusTraversalPolicy$sub_refs	java_awt_DefaultFocusTraversalPolicy;
    _jc_java_awt_ContainerOrderFocusTraversalPolicy$sub_refs	java_awt_ContainerOrderFocusTraversalPolicy;
    _jc_java_awt_FocusTraversalPolicy$sub_refs	java_awt_FocusTraversalPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_DefaultFocusTraversalPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FocusTraversalPolicy$sub_nonrefs	java_awt_FocusTraversalPolicy;
    _jc_java_awt_ContainerOrderFocusTraversalPolicy$sub_nonrefs	java_awt_ContainerOrderFocusTraversalPolicy;
    _jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs	java_awt_DefaultFocusTraversalPolicy;
};

// Object instance structure
struct _jc_java_awt_DefaultFocusTraversalPolicy$object {
	_jc_java_awt_DefaultFocusTraversalPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_DefaultFocusTraversalPolicy$vtype	*vtype;
	_jc_java_awt_DefaultFocusTraversalPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_DefaultFocusTraversalPolicy$vtype _jc_java_awt_DefaultFocusTraversalPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_DefaultFocusTraversalPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_DefaultFocusTraversalPolicy$class_object;

#endif	/* _JC_java_awt_DefaultFocusTraversalPolicy_H_ */

==> jc-1.4.6.tar.gz: java/awt/DefaultFocusTraversalPolicy.h <==
// public class java.awt.DefaultFocusTraversalPolicy

// class file dependencies
// @dep_class 4ebbf65a7d711c64 java_awt_ContainerOrderFocusTraversalPolicy
// @dep_class a5212854707fc4d5 java_awt_DefaultFocusTraversalPolicy
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_ContainerOrderFocusTraversalPolicy

#include "java/awt/ContainerOrderFocusTraversalPolicy.h"

#ifndef _JC_java_awt_DefaultFocusTraversalPolicy_H_
#define _JC_java_awt_DefaultFocusTraversalPolicy_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_refs	_jc_java_awt_DefaultFocusTraversalPolicy$sub_refs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs	_jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$refs	_jc_java_awt_DefaultFocusTraversalPolicy$refs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$nonrefs	_jc_java_awt_DefaultFocusTraversalPolicy$nonrefs;
typedef struct _jc_java_awt_DefaultFocusTraversalPolicy$object	_jc_java_awt_DefaultFocusTraversalPolicy$object;

typedef const struct _jc_java_awt_DefaultFocusTraversalPolicy$vmethods	_jc_java_awt_DefaultFocusTraversalPolicy$vmethods;
typedef const struct _jc_java_awt_DefaultFocusTraversalPolicy$vtable	_jc_java_awt_DefaultFocusTraversalPolicy$vtable;
typedef const struct _jc_java_awt_DefaultFocusTraversalPolicy$vtype	_jc_java_awt_DefaultFocusTraversalPolicy$vtype;

// Constructors
extern void _jc_java_awt_DefaultFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_DefaultFocusTraversalPolicy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_DefaultFocusTraversalPolicy$method$accept$ef92c67fd1dc07ff(_jc_env *, struct _jc_java_awt_DefaultFocusTraversalPolicy$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_DefaultFocusTraversalPolicy$method_info$accept$ef92c67fd1dc07ff;

// Virtual methods structure
struct _jc_java_awt_DefaultFocusTraversalPolicy$vmethods {
	jboolean	(*accept$ef92c67fd1dc07ff)(_jc_env *, struct _jc_java_awt_DefaultFocusTraversalPolicy$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_DefaultFocusTraversalPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FocusTraversalPolicy$vmethods	java_awt_FocusTraversalPolicy;
	_jc_java_awt_ContainerOrderFocusTraversalPolicy$vmethods	java_awt_ContainerOrderFocusTraversalPolicy;
	_jc_java_awt_DefaultFocusTraversalPolicy$vmethods	java_awt_DefaultFocusTraversalPolicy;
};

// Vtype
struct _jc_java_awt_DefaultFocusTraversalPolicy$vtype {
	_jc_type			type;
	_jc_java_awt_DefaultFocusTraversalPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_DefaultFocusTraversalPolicy$refs {
    _jc_java_awt_DefaultFocusTraversalPolicy$sub_refs	java_awt_DefaultFocusTraversalPolicy;
    _jc_java_awt_ContainerOrderFocusTraversalPolicy$sub_refs	java_awt_ContainerOrderFocusTraversalPolicy;
    _jc_java_awt_FocusTraversalPolicy$sub_refs	java_awt_FocusTraversalPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_DefaultFocusTraversalPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FocusTraversalPolicy$sub_nonrefs	java_awt_FocusTraversalPolicy;
    _jc_java_awt_ContainerOrderFocusTraversalPolicy$sub_nonrefs	java_awt_ContainerOrderFocusTraversalPolicy;
    _jc_java_awt_DefaultFocusTraversalPolicy$sub_nonrefs	java_awt_DefaultFocusTraversalPolicy;
};

// Object instance structure
struct _jc_java_awt_DefaultFocusTraversalPolicy$object {
	_jc_java_awt_DefaultFocusTraversalPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_DefaultFocusTraversalPolicy$vtype	*vtype;
	_jc_java_awt_DefaultFocusTraversalPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_DefaultFocusTraversalPolicy$vtype _jc_java_awt_DefaultFocusTraversalPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_DefaultFocusTraversalPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_DefaultFocusTraversalPolicy$class_object;

#endif	/* _JC_java_awt_DefaultFocusTraversalPolicy_H_ */
